#### Load packages ####
library(tidyverse)
library(phyloseq)
library(vegan)
library(ape)

#### Upload files ####
metafp <- "parkinsons_metadata.txt"
meta <- read_delim(metafp, delim="\t")
otufp <- "feature-table_new.txt"
otu <- read_delim(file = otufp, delim="\t", skip=1)
taxfp <- "taxonomy.tsv"
tax <- read_delim(taxfp, delim="\t")
phylotree <- "rooted_tree.nwk"
phylotree <- read.tree(phylotree)

#### Format data ahead of creating Phyloseq object ####
## Format Feature Table and Metadata ahead of generating a Phyloseq object
otu_mat <- as.matrix(otu[,-1])
rownames(otu_mat) <- otu$`#OTU ID`
OTU <- otu_table(otu_mat, taxa_are_rows = T) 

samp_df <- as.data.frame(meta[,-1])
rownames(samp_df)<- meta$`#SampleID`

## Conversion of 1-0 numerical values to Yes-No
samp_df$entacapone<-ifelse(samp_df$entacapone==1,"Yes","No")
samp_df$pramipexole<-ifelse(samp_df$pramipexole==1,"Yes","No")
samp_df$rasagiline<-ifelse(samp_df$rasagiline==1,"Yes","No")
samp_df$amantadine<-ifelse(samp_df$amantadine==1,"Yes","No")
samp_df$IBS<-ifelse(samp_df$IBS==1,"Yes","No")
samp_df$Laxative_use<-ifelse(samp_df$Laxative_use==1,"Yes","No")
samp_df$Constipation_any<-ifelse(samp_df$Constipation_any==1,"Yes","No")
samp_df$Depressed<-ifelse(samp_df$Depressed==1,"Yes","No")
samp_df$BDIOver5<-ifelse(samp_df$BDIOver5==1,"Yes","No")

# Define new categorical variable for Bristol Score 
samp_df <- within(samp_df, {   
  Bristol.cat <- NA # need to initialize variable
  Bristol.cat[Bristol < 3] <- "Constipated"
  Bristol.cat[Bristol >= 3 & Bristol < 5] <- "Normal"
  Bristol.cat[Bristol >= 5] <- "Diarrheal"
} )

SAMP <- sample_data(samp_df)

# Reformat taxa table; already split by domain, phylum, class etc, 
# but includes confd. values
taxa <- tax %>% 
  separate(col=`Feature ID Taxon Confidence`, sep=" "
           , into = c("Feature ID","Domain"))

taxa <- taxa %>% 
  separate(col=`...5`, sep=" "
           , into = c("...5","ConsensusFamily")) %>%
  separate(col=`...6`, sep=" "
           , into = c("...6","ConsensusGenus")) %>%
  separate(col=`...7`, sep=" "
           , into = c("...7","ConsensusSpecies"))

taxa <- taxa %>% 
  select(-ConsensusFamily, -ConsensusGenus, -ConsensusSpecies)

# Rename column names from the taxa table
colnames(taxa)[3] = "Phylum"
colnames(taxa)[4] = "Class"
colnames(taxa)[5] = "Order"
colnames(taxa)[6] = "Family"
colnames(taxa)[7] = "Genus"
colnames(taxa)[8] ="Species"

taxa <- filter(taxa,  
               Domain == "d__Bacteria" & 
                 Class!="c__Chloroplast" & Family !="f__Mitochondria")

# Reformat taxa table
taxa_matrix <- as.matrix(taxa[,-1])
rownames(taxa_matrix) <- taxa$`Feature ID`
TAX <- tax_table(taxa_matrix)

#### Make Phyloseq object ####
PARKINSONS <- phyloseq(OTU, SAMP, TAX, tree=phylotree)
ALL_DATA <- data.frame(sample_data(PARKINSONS))
nrow(ALL_DATA)

# Filter to include only those with PD; we are interested in possible confounders
# among the PD group only
DISEASE_ONLY <- subset_samples(PARKINSONS, Disease == "PD")
DISEASE_ONLY
DISEASE_RARE <- rarefy_even_depth(DISEASE_ONLY, rngseed = 1, sample.size = 3797)

#### Need to remove NA values before proceeding with alpha and beta diversity analyses ####
library(microViz)
PD_INCRM <- ps_drop_incomplete(DISEASE_RARE, vars = "levo_equiv_dose", verbose = TRUE)
PD_INCRM <- ps_drop_incomplete(DISEASE_RARE, vars = "entacapone", verbose = TRUE)

DISEASE_DATA <- data.frame(sample_data(DISEASE_RARE))
DISEASE_RARE_DATA <- data.frame(sample_data(PD_INCRM))
DISEASE_ONLY_DATA <- data.frame(sample_data(DISEASE_ONLY))

#### Recalculating alpha-diversity metrics to ID confounders ####
alphadiv <- estimate_richness(PD_INCRM)
DISEASE_DATA <- data.frame(sample_data(PD_INCRM))
sampdatwdiv <- data.frame(DISEASE_DATA, alphadiv)

lm_Shannon <- lm(Shannon ~ Abdominal_discomfort, data = sampdatwdiv)
summary(lm_Shannon) # 0.295
lm_Shannon <- lm(Shannon ~ IBS, data = sampdatwdiv)
summary(lm_Shannon) # 0.36
lm_Shannon <- lm(Shannon ~ Constipation_RomeIII_status, data = sampdatwdiv)
summary(lm_Shannon) # 0.291
lm_Shannon <- lm(Shannon ~ Constipation_severity_score, data = sampdatwdiv)
summary(lm_Shannon) # 0.448
lm_Shannon <- lm(Shannon ~ Laxative_use, data = sampdatwdiv)
summary(lm_Shannon) # 0.645
lm_Shannon <- lm(Shannon ~ BMI, data = sampdatwdiv)
summary(lm_Shannon) # 0.746
lm_Shannon <- lm(Shannon ~ Age, data = sampdatwdiv)
summary(lm_Shannon) # 0.00428 **
lm_Shannon <- lm(Shannon ~ Age_onset, data = sampdatwdiv)
summary(lm_Shannon) # 0.00303 **
lm_Shannon <- lm(Shannon ~ Disease_dur, data = sampdatwdiv)
summary(lm_Shannon) # 0.527
lm_Shannon <- lm(Shannon ~ BDI_depression_score, data = sampdatwdiv)
summary(lm_Shannon) # 0.836
lm_Shannon <- lm(Shannon ~ Depressed, data = sampdatwdiv)
summary(lm_Shannon) # 0.927
lm_Shannon <- lm(Shannon ~ BDIOver5, data = sampdatwdiv)
summary(lm_Shannon) # 0.639
lm_Shannon <- lm(Shannon ~ FSS_fatigue_score, data = sampdatwdiv)
summary(lm_Shannon) # 0.215
lm_Shannon <- lm(Shannon ~ STAI_anxiety_score, data = sampdatwdiv)
summary(lm_Shannon) # 0.603
lm_Shannon <- lm(Shannon ~ updrstotal, data = sampdatwdiv)
summary(lm_Shannon) # 0.0675 . 
lm_Shannon <- lm(Shannon ~ education, data = sampdatwdiv)
summary(lm_Shannon) # 0.776. 
lm_Shannon <- lm(Shannon ~ moca_total, data = sampdatwdiv)
summary(lm_Shannon) # 0.263
lm_Shannon <- lm(Shannon ~ sniffintotal, data = sampdatwdiv)
summary(lm_Shannon) # 0.776
lm_Shannon <- lm(Shannon ~ Bristol, data = sampdatwdiv)
summary(lm_Shannon) # 0.00416
lm_Shannon <- lm(Shannon ~ Apathy_score, data = sampdatwdiv)
summary(lm_Shannon) # 0.441
lm_Shannon <- lm(Shannon ~ Abx_doses_last_5_years, data = sampdatwdiv)
summary(lm_Shannon) # 0.303
lm_Shannon <- lm(Shannon ~ Alpha_carotene, data = sampdatwdiv)
summary(lm_Shannon) # 0.467
lm_Shannon <- lm(Shannon ~ Alcohol, data = sampdatwdiv)
summary(lm_Shannon) # 0.606
lm_Shannon <- lm(Shannon ~ Beta_carotene, data = sampdatwdiv)
summary(lm_Shannon) # 0.827
lm_Shannon <- lm(Shannon ~ Carotene_total, data = sampdatwdiv)
summary(lm_Shannon) # 0.844
lm_Shannon <- lm(Shannon ~ Calcium, data = sampdatwdiv)
summary(lm_Shannon) # 0.45
lm_Shannon <- lm(Shannon ~ Carbohydrate_total, data = sampdatwdiv)
summary(lm_Shannon) # 0.624
lm_Shannon <- lm(Shannon ~ Cholesterol, data = sampdatwdiv)
summary(lm_Shannon) # 0.969
lm_Shannon <- lm(Shannon ~ Chloride, data = sampdatwdiv)
summary(lm_Shannon) # 0.691
lm_Shannon <- lm(Shannon ~ Copper, data = sampdatwdiv)
summary(lm_Shannon) # 0.865
lm_Shannon <- lm(Shannon ~ Iron, data = sampdatwdiv)
summary(lm_Shannon) # 0.261
lm_Shannon <- lm(Shannon ~ Non_Starch_Polysaccharides, data = sampdatwdiv)
summary(lm_Shannon) # 0.525
lm_Shannon <- lm(Shannon ~ Total_folate, data = sampdatwdiv)
summary(lm_Shannon) # 0.15
lm_Shannon <- lm(Shannon ~ Fructose, data = sampdatwdiv)
summary(lm_Shannon) # 0.159
lm_Shannon <- lm(Shannon ~ Galactose, data = sampdatwdiv)
summary(lm_Shannon) # 0.584
lm_Shannon <- lm(Shannon ~ Glucose, data = sampdatwdiv)
summary(lm_Shannon) # 0.213
lm_Shannon <- lm(Shannon ~ Iodine, data = sampdatwdiv)
summary(lm_Shannon) # 0.406
lm_Shannon <- lm(Shannon ~ Potassium, data = sampdatwdiv)
summary(lm_Shannon) # 0.726
lm_Shannon <- lm(Shannon ~ Energy_kcal, data = sampdatwdiv)
summary(lm_Shannon) # 0.929
lm_Shannon <- lm(Shannon ~ Lactose, data = sampdatwdiv)
summary(lm_Shannon) # 0.268
lm_Shannon <- lm(Shannon ~ Maltose, data = sampdatwdiv)
summary(lm_Shannon) # 0.606
lm_Shannon <- lm(Shannon ~ Manganese, data = sampdatwdiv)
summary(lm_Shannon) # 0.828
lm_Shannon <- lm(Shannon ~ Sodium, data = sampdatwdiv)
summary(lm_Shannon) # 0.592
lm_Shannon <- lm(Shannon ~ Niacin, data = sampdatwdiv)
summary(lm_Shannon) # 0.843


lm_Shannon <- lm(Shannon ~ Phosphorus, data = sampdatwdiv)
summary(lm_Shannon) # 0.622
lm_Shannon <- lm(Shannon ~ Protein, data = sampdatwdiv)
summary(lm_Shannon) # 0.791
lm_Shannon <- lm(Shannon ~ Vitamin_A, data = sampdatwdiv)
summary(lm_Shannon) # 0.586
lm_Shannon <- lm(Shannon ~ Vitamin_B2, data = sampdatwdiv)
summary(lm_Shannon) # 0.0167 *
lm_Shannon <- lm(Shannon ~ Vitamin_B1, data = sampdatwdiv)
summary(lm_Shannon) # 0.73
lm_Shannon <- lm(Shannon ~ Vitamin_B12, data = sampdatwdiv)
summary(lm_Shannon) # 0.325
lm_Shannon <- lm(Shannon ~ Vitamin_B6, data = sampdatwdiv)
summary(lm_Shannon) # 0.488
lm_Shannon <- lm(Shannon ~ Vitamin_C, data = sampdatwdiv)
summary(lm_Shannon) # 0.339
lm_Shannon <- lm(Shannon ~ Vitamin_D, data = sampdatwdiv)
summary(lm_Shannon) # 0.925
lm_Shannon <- lm(Shannon ~ Vitamin_E, data = sampdatwdiv)
summary(lm_Shannon) # 0.537
lm_Shannon <- lm(Shannon ~ Selenium, data = sampdatwdiv)
summary(lm_Shannon) # 0.815
lm_Shannon <- lm(Shannon ~ Starch, data = sampdatwdiv)
summary(lm_Shannon) # 0.881
lm_Shannon <- lm(Shannon ~ Sucrose, data = sampdatwdiv)
summary(lm_Shannon) # 0.535
lm_Shannon <- lm(Shannon ~ Nitrogen, data = sampdatwdiv)
summary(lm_Shannon) # 0.831
lm_Shannon <- lm(Shannon ~ Sugars_total, data = sampdatwdiv)
summary(lm_Shannon) # 0.222
lm_Shannon <- lm(Shannon ~ Zinc, data = sampdatwdiv)
summary(lm_Shannon) # 0.697
lm_Shannon <- lm(Shannon ~ Fat_total, data = sampdatwdiv)
summary(lm_Shannon) # 0.409
lm_Shannon <- lm(Shannon ~ MUFA, data = sampdatwdiv)
summary(lm_Shannon) # 0.188
lm_Shannon <- lm(Shannon ~ PUFA, data = sampdatwdiv)
summary(lm_Shannon) # 0.277
lm_Shannon <- lm(Shannon ~ SFA, data = sampdatwdiv)
summary(lm_Shannon) # 0.968
lm_Shannon <- lm(Shannon ~ Eggs, data = sampdatwdiv)
summary(lm_Shannon) # 0.885
lm_Shannon <- lm(Shannon ~ Alcoholic_beverages, data = sampdatwdiv)
summary(lm_Shannon) # 0.57


lm_Shannon <- lm(Shannon ~ Cereals, data = sampdatwdiv)
summary(lm_Shannon) # 0.971
lm_Shannon <- lm(Shannon ~ Fats_and_oils, data = sampdatwdiv)
summary(lm_Shannon) # 0.517
lm_Shannon <- lm(Shannon ~ Fish, data = sampdatwdiv)
summary(lm_Shannon) # 0.37
lm_Shannon <- lm(Shannon ~ Fruit, data = sampdatwdiv)
summary(lm_Shannon) # 0.28
lm_Shannon <- lm(Shannon ~ Meat, data = sampdatwdiv)
summary(lm_Shannon) # 0.939
lm_Shannon <- lm(Shannon ~ Milk, data = sampdatwdiv)
summary(lm_Shannon) # 0.138
lm_Shannon <- lm(Shannon ~ Non_alcoholic_bevs, data = sampdatwdiv)
summary(lm_Shannon) # 0.793
lm_Shannon <- lm(Shannon ~ Nuts_and_seeds, data = sampdatwdiv)
summary(lm_Shannon) # 0.0243 *
lm_Shannon <- lm(Shannon ~ Potatoes, data = sampdatwdiv)
summary(lm_Shannon) # 0.225
lm_Shannon <- lm(Shannon ~ Soups_sauces, data = sampdatwdiv)
summary(lm_Shannon) # 0.915
lm_Shannon <- lm(Shannon ~ Preserves_and_snacks, data = sampdatwdiv)
summary(lm_Shannon) # 0.242
lm_Shannon <- lm(Shannon ~ Fats_and_oils, data = sampdatwdiv)
summary(lm_Shannon) # 0.517
lm_Shannon <- lm(Shannon ~ Vegetables, data = sampdatwdiv)
summary(lm_Shannon) # 0.664

#### Looking a LED attributable to L-dopa only ####
NO_DRUGS <- subset_samples(PD_INCRM, pramipexole == "No" & entacapone == "No" &
                             rasagiline == "No" & amantadine == "No")
alphadiv_Levo <- estimate_richness(NO_DRUGS)
DISEASE_LEVO_DATA <- data.frame(sample_data(NO_DRUGS))
sampdatwdiv_Levo <- data.frame(DISEASE_LEVO_DATA, alphadiv_Levo)

lm_Shannon <- lm(Shannon ~ levo_equiv_dose, data = sampdatwdiv_Levo)
summary(lm_Shannon) # 0.267
lm_Chao1 <- lm(Chao1 ~ levo_equiv_dose, data = sampdatwdiv_Levo)
summary(lm_Chao1) # 0.604
lm_Fisher <- lm(Fisher ~ levo_equiv_dose, data = sampdatwdiv_Levo)
summary(lm_Fisher) # 0.563

# Generate a linear regression plot
ggplot(sampdatwdiv_Levo, aes(x = levo_equiv_dose, y = Shannon)) + 
  geom_point(color='#192b4d') +
  stat_smooth(method = "lm", color ="#3c91ab") +
  labs(x ="LED") +   labs(x ="LED") + theme(panel.background=element_rect(colour="black")) +
  theme_bw() 

#### Restrict samples to PD_L and PD_LE Samples ####
DISEASE_EL <- subset_samples(PD_INCRM, rasagiline=="No" & 
                               pramipexole=="No" & amantadine=="No")

E_ONLY <- subset_samples(PD_INCRM, entacapone == "Yes")
NO_DRUGS <- subset_samples(PD_INCRM, pramipexole == "No" & entacapone == "No" &
                             rasagiline == "No" & amantadine == "No")
E_NODRUG <- merge_phyloseq(E_ONLY, NO_DRUGS)

# Entacapone does not affect Shannon diversity,
wilcox.test(sampdatwdiv$Shannon ~ sampdatwdiv$entacapone) # p-value = 0.2355 
wilcox.test(sampdatwdiv$Chao1 ~ sampdatwdiv$entacapone) # p-value = 0.1144

# Display both Shannon and Chao1 metrics
plot_richness(E_NODRUG, measures = c("Shannon","Chao1")) +
  geom_boxplot(aes(fill = entacapone),
               position = position_dodge(0.9),coef = 6) +
  geom_dotplot( aes(fill = entacapone),
                binaxis='y', stackdir='center', dotsize = 0.4,
                position = position_dodge(0.9)) + 
  theme_bw()

# Shannon diversity metrics only
plot_richness(E_NODRUG, measures = c("Shannon")) +
  geom_boxplot(aes(fill = entacapone),
               position = position_dodge(0.9), alpha = 0.5) +
  geom_signif( y_position = c(5), xmin = c(0.75), xmax = c(1.25),
               annotation = c("*"), tip_length = 0.01) +
  geom_dotplot( aes(fill = entacapone),
                binaxis='y', stackdir='center', dotsize = 0.4,
                position = position_dodge(0.9)) + 
  theme_bw()
