#### Load packages ####
library(tidyverse)
library(phyloseq)
library(vegan)
library(ape)

#### Upload files ####
metafp <- "parkinsons_metadata.txt"
meta <- read_delim(metafp, delim="\t")
otufp <- "feature-table_new.txt"
otu <- read_delim(file = otufp, delim="\t", skip=1)
taxfp <- "taxonomy.tsv"
tax <- read_delim(taxfp, delim="\t")
phylotree <- "rooted_tree.nwk"
phylotree <- read.tree(phylotree)

#### Format data ahead of creating Phyloseq object ####
## Format Feature Table and Metadata ahead of generating a Phyloseq object
otu_mat <- as.matrix(otu[,-1])
rownames(otu_mat) <- otu$`#OTU ID`
OTU <- otu_table(otu_mat, taxa_are_rows = T) 

samp_df <- as.data.frame(meta[,-1])
rownames(samp_df)<- meta$`#SampleID`

## Conversion of 1-0 numerical values to Yes-No
samp_df$entacapone<-ifelse(samp_df$entacapone==1,"Yes","No")
samp_df$pramipexole<-ifelse(samp_df$pramipexole==1,"Yes","No")
samp_df$rasagiline<-ifelse(samp_df$rasagiline==1,"Yes","No")
samp_df$amantadine<-ifelse(samp_df$amantadine==1,"Yes","No")
samp_df$IBS<-ifelse(samp_df$IBS==1,"Yes","No")
samp_df$Laxative_use<-ifelse(samp_df$Laxative_use==1,"Yes","No")
samp_df$Constipation_any<-ifelse(samp_df$Constipation_any==1,"Yes","No")
samp_df$Depressed<-ifelse(samp_df$Depressed==1,"Yes","No")
samp_df$BDIOver5<-ifelse(samp_df$BDIOver5==1,"Yes","No")

# Define new categorical variable for Bristol Score 
samp_df <- within(samp_df, {   
  Bristol.cat <- NA # need to initialize variable
  Bristol.cat[Bristol < 3] <- "Constipated"
  Bristol.cat[Bristol >= 3 & Bristol < 5] <- "Normal"
  Bristol.cat[Bristol >= 5] <- "Diarrheal"
} )

SAMP <- sample_data(samp_df)

# Reformat taxa table; already split by domain, phylum, class etc, 
# but includes confd. values
taxa <- tax %>% 
  separate(col=`Feature ID Taxon Confidence`, sep=" "
           , into = c("Feature ID","Domain"))

taxa <- taxa %>% 
  separate(col=`...5`, sep=" "
           , into = c("...5","ConsensusFamily")) %>%
  separate(col=`...6`, sep=" "
           , into = c("...6","ConsensusGenus")) %>%
  separate(col=`...7`, sep=" "
           , into = c("...7","ConsensusSpecies"))

taxa <- taxa %>% 
  select(-ConsensusFamily, -ConsensusGenus, -ConsensusSpecies)

# Rename column names from the taxa table
colnames(taxa)[3] = "Phylum"
colnames(taxa)[4] = "Class"
colnames(taxa)[5] = "Order"
colnames(taxa)[6] = "Family"
colnames(taxa)[7] = "Genus"
colnames(taxa)[8] ="Species"

taxa <- filter(taxa,  
               Domain == "d__Bacteria" & 
                 Class!="c__Chloroplast" & Family !="f__Mitochondria")

# Reformat taxa table
taxa_matrix <- as.matrix(taxa[,-1])
rownames(taxa_matrix) <- taxa$`Feature ID`
TAX <- tax_table(taxa_matrix)

#### Make Phyloseq object ####
PARKINSONS <- phyloseq(OTU, SAMP, TAX, tree=phylotree)
ALL_DATA <- data.frame(sample_data(PARKINSONS))
nrow(ALL_DATA)

# Filter to include only those with PD; we are interested in possible confounders
# among the PD group only
DISEASE_ONLY <- subset_samples(PARKINSONS, Disease == "PD")
DISEASE_ONLY
DISEASE_RARE <- rarefy_even_depth(DISEASE_ONLY, rngseed = 1, sample.size = 3797)

#### Need to remove NA values before proceeding with alpha and beta diversity analyses ####
library(microViz)
PD_INCRM <- ps_drop_incomplete(DISEASE_RARE, vars = "levo_equiv_dose", verbose = TRUE)
PD_INCRM <- ps_drop_incomplete(DISEASE_RARE, vars = "entacapone", verbose = TRUE)

DISEASE_DATA <- data.frame(sample_data(DISEASE_RARE))
DISEASE_RARE_DATA <- data.frame(sample_data(PD_INCRM))
DISEASE_ONLY_DATA <- data.frame(sample_data(DISEASE_ONLY))

#### Calculate beta diversity metrics ####
dm_wunifrac <- UniFrac(PD_INCRM, weighted=TRUE)

#### Are there any varaiables that may be confounders? ####
adonis2(dm_wunifrac ~ levo_equiv_dose, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.075; near-significant
adonis2(dm_wunifrac ~ Constipation_severity_score, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.028 *
adonis2(dm_wunifrac ~ Laxative_use, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.022 *
adonis2(dm_wunifrac ~ Age, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.8
adonis2(dm_wunifrac ~ Age_onset, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.661
adonis2(dm_wunifrac ~ Disease_dur, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.195
adonis2(dm_wunifrac ~ Bristol, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.001 ***
adonis2(dm_wunifrac ~ Age, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.8
adonis2(dm_wunifrac ~ IBS, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.899
adonis2(dm_wunifrac ~ Depressed, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.562
adonis2(dm_wunifrac ~ BDIOver5, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.221
adonis2(dm_wunifrac ~ Sex, data=DISEASE_RARE_DATA) # Pr(>F) value = 0.802

#### Do these confounders effect one another, and by how much if yes? ####
kruskal.test(Bristol ~ Laxative_use, data = DISEASE_RARE_DATA) # p-value = 0.00292 **
kruskal.test(Laxative_use ~ Bristol, data = DISEASE_RARE_DATA) # p-value = 0.0518 . 

kruskal.test(Bristol ~ Constipation_severity_score, data = DISEASE_RARE_DATA) # p-value = 0.0389 *
kruskal.test(Constipation_severity_score ~ Bristol, data = DISEASE_RARE_DATA) # p-value = 0.00128 **

kruskal.test(Constipation_severity_score ~ Laxative_use, data = DISEASE_RARE_DATA) # p-value = 5.214e-07 **
kruskal.test(Laxative_use ~ Constipation_severity_score, data = DISEASE_RARE_DATA) # p-value = 0.00602 **

#### Isolating L-dopa-treated patients only ####
LEVO_ONLY <- subset_samples(PD_INCRM, entacapone == "No" & amantadine == "No" & rasagiline == "No"
                            & pramipexole == "No")
LEVO_ONLY_DATA <- data.frame(sample_data(LEVO_ONLY))

#### Compute beta-diversity metrics ####
dm_wunifrac_levo <- UniFrac(LEVO_ONLY, weighted=TRUE)
dm_unifrac_levo <- UniFrac(LEVO_ONLY, weighted=FALSE)
dm_bray_levo <- vegdist(t(otu_table(LEVO_ONLY)), method="bray")
dm_jaccard_levo <- vegdist(t(otu_table(LEVO_ONLY)), method="jaccard")

adonis2(dm_wunifrac_levo ~ levo_equiv_dose, data=LEVO_ONLY_DATA) # Pr(>F) value = 0.672
adonis2(dm_unifrac_levo ~ levo_equiv_dose, data=LEVO_ONLY_DATA) # Pr(>F) value = 0.51
adonis2(dm_bray_levo ~ levo_equiv_dose, data=LEVO_ONLY_DATA) # Pr(>F) value = 0.414
adonis2(dm_jaccard_levo ~ levo_equiv_dose, data=LEVO_ONLY_DATA) # Pr(>F) value = 0.334
## Therefore, levo alone does not alter beta-diversity. 

#### Generate ordination plot for PD_L patients only based on LED #### 
library("viridis") 
ld_pcoa_wuni <- ordinate(LEVO_ONLY, method="PCoA", distance=dm_wunifrac_levo)
plot_wuni_ld <- plot_ordination(LEVO_ONLY, ld_pcoa_wuni, 
                                color = "levo_equiv_dose", shape = "Laxative_use") +
  theme_bw() + theme(panel.background=element_rect(colour="black")) +
  scale_color_viridis(option = "D") + 
  labs(col = "LED", shape ="Laxative use") + 
  scale_shape_manual(values = c(16, 4)) 
plot_wuni_ld + stat_ellipse(level = 0.95)

#### Start by looking at entacapone only ####
## Subset Phyloseq object...
E_and_L_ONLY <- subset_samples(PD_INCRM, amantadine == "No" & rasagiline == "No" &
                                 pramipexole == "No")
E_and_L_ONLY_DATA <- data.frame(sample_data(E_and_L_ONLY))

# Then generate beta diversity metrics
dm_wunifrac_el <- UniFrac(E_and_L_ONLY, weighted=TRUE)
dm_unifrac_el <- UniFrac(E_and_L_ONLY, weighted=FALSE)
dm_bray_el <- vegdist(t(otu_table(E_and_L_ONLY)), method="bray")
dm_jaccard_el <- vegdist(t(otu_table(E_and_L_ONLY)), method="jaccard")

# Only PERMANOVA using weighted UniFrac metrics shows near-significant of entacapone 
adonis2(dm_wunifrac_el ~ entacapone, data=E_and_L_ONLY_DATA) # Pr(>F) value = 0.062; near-significance
adonis2(dm_unifrac_el ~ entacapone, data=E_and_L_ONLY_DATA) # Pr(>F) value = 0.604
adonis2(dm_bray_el ~ entacapone, data=E_and_L_ONLY_DATA) # Pr(>F) value = 0.133
adonis2(dm_jaccard_el ~ entacapone, data=E_and_L_ONLY_DATA) # Pr(>F) value = 0.154

#### What if if we account for laxative use? ####
## Subset Phyloseq objects 
E_and_L_ONLY_LAX <- subset_samples(E_and_L_ONLY, Laxative_use == "Yes")
E_and_L_ONLY_NOLAX <- subset_samples(E_and_L_ONLY, Laxative_use == "No")
E_and_L_ONLY_LAX_DATA <- data.frame(sample_data(E_and_L_ONLY_LAX))
E_and_L_ONLY_NOLAX_DATA <- data.frame(sample_data(E_and_L_ONLY_NOLAX))

## Laxative use: Yes; entacapone has a significant effect
dm_wunifrac_el_lax <- UniFrac(E_and_L_ONLY_LAX, weighted=TRUE)
adonis2(dm_wunifrac_el_lax ~ entacapone, data=E_and_L_ONLY_LAX_DATA) # Pr(>F) value = 0.007 **

## Laxative use: No; entacapone does NOT have a significant effect
dm_wunifrac_el_nolax <- UniFrac(E_and_L_ONLY_NOLAX, weighted=TRUE)
adonis2(dm_wunifrac_el_nolax ~ entacapone, data=E_and_L_ONLY_NOLAX_DATA) # Pr(>F) value = 0.185

#### Generate ordination plots for PD_L vs PD_LE patients ####
library(ggplot2) 
library(ggside)
# Make sure to include ellipses that depict the 95% confidence interval 

# Weighted UniFrac, all PD_L and PD_LE subjects
el_pcoa_wuni <- ordinate(E_and_L_ONLY, method="PCoA", distance=dm_wunifrac_el)
plot_wuni <- plot_ordination(E_and_L_ONLY, el_pcoa_wuni, 
                             color = "entacapone") +
  labs(col = "Took entacapone?") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void()
plot_wuni
plot_wuni + stat_ellipse(level = 0.95)

# Unweighted UniFrac, all PD_L and PD_LE subjects
el_pcoa_uni <- ordinate(E_and_L_ONLY, method="PCoA", distance=dm_unifrac_el)
plot_uni <- plot_ordination(E_and_L_ONLY, el_pcoa_uni, 
                            color = "entacapone") +
  labs(col = "Took entacapone?") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void()
plot_uni
plot_uni + stat_ellipse(level = 0.95)

# Bray-Curtis Dissimilarity, all PD_L and PD_LE subjects
el_pcoa_bray <- ordinate(E_and_L_ONLY, method="PCoA", distance=dm_bray_el)
plot_bray <- plot_ordination(E_and_L_ONLY, el_pcoa_bray, 
                             color = "entacapone") +
  labs(col = "Took entacapone?") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void()
plot_bray + stat_ellipse(level = 0.95)

# Jaccard index, all PD_L and PD_LE subjects
el_pcoa_jaccard <- ordinate(E_and_L_ONLY, method="PCoA", distance=dm_jaccard_el)
plot_jaccard <- plot_ordination(E_and_L_ONLY, el_pcoa_jaccard, 
                                color = "entacapone") +
  labs(col = "Took entacapone?") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void()
plot_jaccard + stat_ellipse(level = 0.95)

# Now generate ordination plots by subsetting based on laxative use
# Only laxative users included
el_lax_pcoa_wuni <- ordinate(E_and_L_ONLY_LAX, method="PCoA", distance=dm_wunifrac_el_lax)
plot_wuni_lax <- plot_ordination(E_and_L_ONLY_LAX, el_lax_pcoa_wuni, 
                                 color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() +
  labs(col = "Took entacapone?")
plot_wuni_lax + stat_ellipse(level = 0.95)

# Only non-laxative users included
el_nolax_pcoa_wuni <- ordinate(E_and_L_ONLY_NOLAX, method="PCoA", distance=dm_wunifrac_el_nolax)
plot_wuni_nolax <- plot_ordination(E_and_L_ONLY_NOLAX, el_nolax_pcoa_wuni, 
                                   color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() +
  labs(col = "Took entacapone?")
plot_wuni_nolax + stat_ellipse(level = 0.95)

#### What is the full range of LED values among PD patients? ####
summary(LEVO_ONLY_DATA$levo_equiv_dose)
## Min. 1st Qu.  Median    Mean   3rd Qu.    Max. 
## 0.0   300.0   460.0    540.4   725.0    1475.0 

# Generate a boxplot to show this visually 
levoplot <- ggplot(LEVO_ONLY_DATA, aes(x=levo_equiv_dose)) +
  geom_boxplot(color="#3c91ab") +   
  scale_y_continuous(breaks = seq(by = 1)) +
  xlab("LED")+
  theme_bw() 
levoplot
+ coord_flip()

#### Compare beta diversity metrics while accounting for LED: First quartile ####
# First, generate a phyloseq object that includes PD_LE patients only
E_ONLY <- subset_samples(E_and_L_ONLY_LAX, entacapone == "Yes")

# Next, subset PD_L subjects based on their LED. We will start by including only the patients in the first quartile.
NO_DRUGS_Q1 <- subset_samples(LEVO_ONLY, levo_equiv_dose <= 300.00 & Laxative_use=="Yes")

# Combine both phyloseq objects. 
E_NODRUG_Q1 <- merge_phyloseq(E_ONLY, NO_DRUGS_Q1)
E_NODRUG_Q1_DATA <- data.frame(sample_data(E_NODRUG_Q1))

# Low LED PD_L patients and PD_LE patients are significantly different. 
dm_wunifrac_eq1 <- UniFrac(E_NODRUG_Q1, weighted=TRUE)
adonis2(dm_wunifrac_eq1 ~ entacapone, data=E_NODRUG_Q1_DATA) #  Pr(>F) value = 0.003 ***

# Generate an ordination plot. 
eq1_pcoa_wuni <- ordinate(E_NODRUG_Q1, method="PCoA", distance=dm_wunifrac_eq1)
plot_wuni_eq1 <- plot_ordination(E_NODRUG_Q1, eq1_pcoa_wuni, 
                                 color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() 
plot_wuni_eq1 + stat_ellipse(level = 0.95)

#### Compare beta diversity metrics while accounting for LED: Second quartile ####
# Subset PD_L subjects based on their LED. We are including only the patients in the second quartile.
NO_DRUGS_Q2 <- subset_samples(LEVO_ONLY, levo_equiv_dose > 300.00 & levo_equiv_dose <= 460.00
                              & Laxative_use=="Yes")

# Combine with phyloseq object that includes only laxative-using PD_LE patients.  
E_NODRUG_Q2 <- merge_phyloseq(E_ONLY, NO_DRUGS_Q2)
E_NODRUG_Q2_DATA <- data.frame(sample_data(E_NODRUG_Q2))

# Low-to-moderate LED PD_L patients and PD_LE patients are significantly different. 
dm_wunifrac_eq2 <- UniFrac(E_NODRUG_Q2, weighted=TRUE)
adonis2(dm_wunifrac_eq2 ~ entacapone, data=E_NODRUG_Q2_DATA) # Pr(>F) value = 0.047 *

# Generate an ordination plot. 
eq2_pcoa_wuni <- ordinate(E_NODRUG_Q2, method="PCoA", distance=dm_wunifrac_eq2)
plot_wuni_eq2 <- plot_ordination(E_NODRUG_Q2, eq2_pcoa_wuni, 
                                 color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() 
plot_wuni_eq2 + stat_ellipse(level = 0.95)

#### Compare beta diversity metrics while accounting for LED: Third quartile ####
# Subset PD_L subjects based on their LED. We are including only the patients in the third quartile.
NO_DRUGS_Q3 <- subset_samples(LEVO_ONLY, levo_equiv_dose > 460.00 & levo_equiv_dose <= 725.00
                              & Laxative_use=="Yes")

# Combine with phyloseq object that includes only laxative-using PD_LE patients.  
E_NODRUG_Q3 <- merge_phyloseq(E_ONLY, NO_DRUGS_Q3)
E_NODRUG_Q3_DATA <- data.frame(sample_data(E_NODRUG_Q3))

# Moderate-to-high LED PD_L patients and PD_LE patients are significantly different. 
dm_wunifrac_eq3 <- UniFrac(E_NODRUG_Q3, weighted=TRUE)
adonis2(dm_wunifrac_eq3 ~ entacapone, data=E_NODRUG_Q3_DATA) # Pr(>F) value = 0.038 *

# Generate an ordination plot. 
eq3_pcoa_wuni <- ordinate(E_NODRUG_Q3, method="PCoA", distance=dm_wunifrac_eq3)
plot_wuni_eq3 <- plot_ordination(E_NODRUG_Q3, eq3_pcoa_wuni, 
                                 color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() 
plot_wuni_eq3 + stat_ellipse(level = 0.95)

#### Compare beta diversity metrics while accounting for LED: Fourth quartile ####
# Subset PD_L subjects based on their LED. We are including only the patients in the fourth quartile.
NO_DRUGS_Q4 <- subset_samples(LEVO_ONLY, levo_equiv_dose > 725.00 & Laxative_use=="Yes")

# Combine with phyloseq object that includes only laxative-using PD_LE patients.  
E_NODRUG_Q4 <- merge_phyloseq(E_ONLY, NO_DRUGS_Q4)
E_NODRUG_Q4_DATA <- data.frame(sample_data(E_NODRUG_Q4))

# High LED PD_L patients and PD_LE patients are significantly different. 
dm_wunifrac_eq4 <- UniFrac(E_NODRUG_Q4, weighted=TRUE)
adonis2(dm_wunifrac_eq4 ~ entacapone, data=E_NODRUG_Q4_DATA) # Pr(>F) value = 0.002 **

# Generate an ordination plot. 
eq4_pcoa_wuni <- ordinate(E_NODRUG_Q4, method="PCoA", distance=dm_wunifrac_eq4)
plot_wuni_eq4 <- plot_ordination(E_NODRUG_Q4, eq4_pcoa_wuni, 
                                 color = "entacapone") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  ggside::geom_xsideboxplot(aes(fill = entacapone, y = entacapone), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = entacapone, x = entacapone), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() 
plot_wuni_eq4 + stat_ellipse(level = 0.95)

#### Comparing entacapone users only based on laxative use ####
# Here, we are only considering PD_LE patients. 
E_ONLY <- subset_samples(E_and_L_ONLY, entacapone == "Yes" & Age!=64)
E_ONLY_DATA <- data.frame(sample_data(E_ONLY))

# PD_LE patients that take or do not take laxatives are significantly different. 
dm_wunifrac_eonly <- UniFrac(E_ONLY, weighted=TRUE)
adonis2(dm_wunifrac_eonly ~ Laxative_use, data=E_ONLY_DATA) # Pr(>F) value = 0.045 * 
eonly_pcoa_wuni <- ordinate(E_ONLY, method="PCoA", distance=dm_wunifrac_eonly)

# Generate ordination plot
plot_wuni_eonly <- plot_ordination(E_ONLY, eonly_pcoa_wuni, 
                                   color = "Laxative_use") + theme_bw() +
  scale_colour_manual(values = c("#ab5348", "#4f9e9d")) +
  labs(col = "Laxative use")+
  ggside::geom_xsideboxplot(aes(fill = Laxative_use, y = Laxative_use), orientation = "y") +
  ggside::geom_ysideboxplot(aes(fill = Laxative_use, x = Laxative_use), orientation = "x") +
  ggside::scale_xsidey_discrete(labels = NULL) +
  ggside::scale_ysidex_discrete(labels = NULL) +
  ggside::theme_ggside_void() 
