#### Load packages ####
library(tidyverse)
library(phyloseq)
library(vegan)
library(ape)

#### Upload files ####
metafp <- "parkinsons_metadata.txt"
meta <- read_delim(metafp, delim="\t")
otufp <- "feature-table_new.txt"
otu <- read_delim(file = otufp, delim="\t", skip=1)
taxfp <- "taxonomy.tsv"
tax <- read_delim(taxfp, delim="\t")
phylotree <- "rooted_tree.nwk"
phylotree <- read.tree(phylotree)

#### Format data ahead of creating Phyloseq object ####
## Format Feature Table and Metadata ahead of generating a Phyloseq object
otu_mat <- as.matrix(otu[,-1])
rownames(otu_mat) <- otu$`#OTU ID`
OTU <- otu_table(otu_mat, taxa_are_rows = T) 

samp_df <- as.data.frame(meta[,-1])
rownames(samp_df)<- meta$`#SampleID`

## Conversion of 1-0 numerical values to Yes-No
samp_df$entacapone<-ifelse(samp_df$entacapone==1,"Yes","No")
samp_df$pramipexole<-ifelse(samp_df$pramipexole==1,"Yes","No")
samp_df$rasagiline<-ifelse(samp_df$rasagiline==1,"Yes","No")
samp_df$amantadine<-ifelse(samp_df$amantadine==1,"Yes","No")
samp_df$IBS<-ifelse(samp_df$IBS==1,"Yes","No")
samp_df$Laxative_use<-ifelse(samp_df$Laxative_use==1,"Yes","No")
samp_df$Constipation_any<-ifelse(samp_df$Constipation_any==1,"Yes","No")
samp_df$Depressed<-ifelse(samp_df$Depressed==1,"Yes","No")
samp_df$BDIOver5<-ifelse(samp_df$BDIOver5==1,"Yes","No")

# Define new categorical variable for Bristol Score 
samp_df <- within(samp_df, {   
  Bristol.cat <- NA # need to initialize variable
  Bristol.cat[Bristol < 3] <- "Constipated"
  Bristol.cat[Bristol >= 3 & Bristol < 5] <- "Normal"
  Bristol.cat[Bristol >= 5] <- "Diarrheal"
} )

SAMP <- sample_data(samp_df)

# Reformat taxa table; already split by domain, phylum, class etc, 
# but includes confd. values
taxa <- tax %>% 
  separate(col=`Feature ID Taxon Confidence`, sep=" "
           , into = c("Feature ID","Domain"))

taxa <- taxa %>% 
  separate(col=`...5`, sep=" "
           , into = c("...5","ConsensusFamily")) %>%
  separate(col=`...6`, sep=" "
           , into = c("...6","ConsensusGenus")) %>%
  separate(col=`...7`, sep=" "
           , into = c("...7","ConsensusSpecies"))

taxa <- taxa %>% 
  select(-ConsensusFamily, -ConsensusGenus, -ConsensusSpecies)

# Rename column names from the taxa table
colnames(taxa)[3] = "Phylum"
colnames(taxa)[4] = "Class"
colnames(taxa)[5] = "Order"
colnames(taxa)[6] = "Family"
colnames(taxa)[7] = "Genus"
colnames(taxa)[8] ="Species"

taxa <- filter(taxa,  
               Domain == "d__Bacteria" & 
                 Class!="c__Chloroplast" & Family !="f__Mitochondria")

# Reformat taxa table
taxa_matrix <- as.matrix(taxa[,-1])
rownames(taxa_matrix) <- taxa$`Feature ID`
TAX <- tax_table(taxa_matrix)

#### Make Phyloseq object ####
PARKINSONS <- phyloseq(OTU, SAMP, TAX, tree=phylotree)
ALL_DATA <- data.frame(sample_data(PARKINSONS))
nrow(ALL_DATA)

# Filter to include only those with PD; we are interested in possible confounders
# among the PD group only
DISEASE_ONLY <- subset_samples(PARKINSONS, Disease == "PD")
DISEASE_ONLY
DISEASE_RARE <- rarefy_even_depth(DISEASE_ONLY, rngseed = 1, sample.size = 3797)

#### Need to remove NA values before proceeding with alpha and beta diversity analyses ####
library(microViz)
PD_INCRM <- ps_drop_incomplete(DISEASE_RARE, vars = "levo_equiv_dose", verbose = TRUE)
PD_INCRM <- ps_drop_incomplete(DISEASE_RARE, vars = "entacapone", verbose = TRUE)

DISEASE_DATA <- data.frame(sample_data(DISEASE_RARE))
DISEASE_RARE_DATA <- data.frame(sample_data(PD_INCRM))
DISEASE_ONLY_DATA <- data.frame(sample_data(DISEASE_ONLY))

#### Subset phyloseq object ahead of DESeq2 analysis ####
## include PD_L and PD_LE subjects only
E_and_L_ONLY <- subset_samples(PD_INCRM, amantadine == "No" & rasagiline == "No" & pramipexole == "No")

## Subset by laxative use
E_and_L_ONLY_LAX <- subset_samples(E_and_L_ONLY, Laxative_use == "Yes")
E_and_L_ONLY_NOLAX <- subset_samples(E_and_L_ONLY, Laxative_use == "No")

#### DESeq ####
library(DESeq2)

#### Look at Laxative users first ####
EL_plusone <- transform_sample_counts(E_and_L_ONLY_LAX, function(x) x+1)
EL_deseq <- phyloseq_to_deseq2(EL_plusone, ~entacapone)
DESEQ_Enta_LDOPA <- DESeq(EL_deseq)
res_lax <- results(DESEQ_Enta_LDOPA, tidy=TRUE)
View(res_lax)

# No significant results re: adjusted p-values, but many hits for unadjusted p-values 

## Volcano plot
ggplot(res_lax) +
  geom_point(aes(x=log2FoldChange, y=-log10(padj)))

res_lax %>%
  mutate(significant = pvalue<0.01 & abs(log2FoldChange)>2) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant))

sigASVs <- res_lax %>% 
  filter(pvalue<0.01 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)
View(sigASVs)

sigASVs_vec <- sigASVs %>%
  pull(ASV)

#### Now look at non-laxative users ####
ELnolax_plusone <- transform_sample_counts(E_and_L_ONLY_NOLAX, function(x) x+1)
ELnolax_deseq <- phyloseq_to_deseq2(EL_plusone, ~entacapone)
DESEQ_Enta_LDOPA_nolax <- DESeq(ELnolax_deseq)
res_nolax <- results(DESEQ_Enta_LDOPA_nolax, tidy=TRUE)
View(res_nolax)

## Volcano plot
ggplot(res_nolax) +
  geom_point(aes(x=log2FoldChange, y=-log10(padj)))

res_nolax %>%
  mutate(significant = padj<0.01 & abs(log2FoldChange)>2) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant))

sigASVs <- res_nolax %>% 
  filter(padj<0.01 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)
View(sigASVs)

sigASVs_vec <- sigASVs %>%
  pull(ASV)